import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { CloudFrontClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CloudFrontClient";
import { GetFieldLevelEncryptionConfigRequest, GetFieldLevelEncryptionConfigResult } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetFieldLevelEncryptionConfigCommand}.
 */
export interface GetFieldLevelEncryptionConfigCommandInput extends GetFieldLevelEncryptionConfigRequest {
}
/**
 * @public
 *
 * The output of {@link GetFieldLevelEncryptionConfigCommand}.
 */
export interface GetFieldLevelEncryptionConfigCommandOutput extends GetFieldLevelEncryptionConfigResult, __MetadataBearer {
}
declare const GetFieldLevelEncryptionConfigCommand_base: {
    new (input: GetFieldLevelEncryptionConfigCommandInput): import("@smithy/smithy-client").CommandImpl<GetFieldLevelEncryptionConfigCommandInput, GetFieldLevelEncryptionConfigCommandOutput, CloudFrontClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: GetFieldLevelEncryptionConfigCommandInput): import("@smithy/smithy-client").CommandImpl<GetFieldLevelEncryptionConfigCommandInput, GetFieldLevelEncryptionConfigCommandOutput, CloudFrontClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Get the field-level encryption configuration information.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudFrontClient, GetFieldLevelEncryptionConfigCommand } from "@aws-sdk/client-cloudfront"; // ES Modules import
 * // const { CloudFrontClient, GetFieldLevelEncryptionConfigCommand } = require("@aws-sdk/client-cloudfront"); // CommonJS import
 * const client = new CloudFrontClient(config);
 * const input = { // GetFieldLevelEncryptionConfigRequest
 *   Id: "STRING_VALUE", // required
 * };
 * const command = new GetFieldLevelEncryptionConfigCommand(input);
 * const response = await client.send(command);
 * // { // GetFieldLevelEncryptionConfigResult
 * //   FieldLevelEncryptionConfig: { // FieldLevelEncryptionConfig
 * //     CallerReference: "STRING_VALUE", // required
 * //     Comment: "STRING_VALUE",
 * //     QueryArgProfileConfig: { // QueryArgProfileConfig
 * //       ForwardWhenQueryArgProfileIsUnknown: true || false, // required
 * //       QueryArgProfiles: { // QueryArgProfiles
 * //         Quantity: Number("int"), // required
 * //         Items: [ // QueryArgProfileList
 * //           { // QueryArgProfile
 * //             QueryArg: "STRING_VALUE", // required
 * //             ProfileId: "STRING_VALUE", // required
 * //           },
 * //         ],
 * //       },
 * //     },
 * //     ContentTypeProfileConfig: { // ContentTypeProfileConfig
 * //       ForwardWhenContentTypeIsUnknown: true || false, // required
 * //       ContentTypeProfiles: { // ContentTypeProfiles
 * //         Quantity: Number("int"), // required
 * //         Items: [ // ContentTypeProfileList
 * //           { // ContentTypeProfile
 * //             Format: "URLEncoded", // required
 * //             ProfileId: "STRING_VALUE",
 * //             ContentType: "STRING_VALUE", // required
 * //           },
 * //         ],
 * //       },
 * //     },
 * //   },
 * //   ETag: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param GetFieldLevelEncryptionConfigCommandInput - {@link GetFieldLevelEncryptionConfigCommandInput}
 * @returns {@link GetFieldLevelEncryptionConfigCommandOutput}
 * @see {@link GetFieldLevelEncryptionConfigCommandInput} for command's `input` shape.
 * @see {@link GetFieldLevelEncryptionConfigCommandOutput} for command's `response` shape.
 * @see {@link CloudFrontClientResolvedConfig | config} for CloudFrontClient's `config` shape.
 *
 * @throws {@link AccessDenied} (client fault)
 *  <p>Access denied.</p>
 *
 * @throws {@link NoSuchFieldLevelEncryptionConfig} (client fault)
 *  <p>The specified configuration for field-level encryption doesn't exist.</p>
 *
 * @throws {@link CloudFrontServiceException}
 * <p>Base exception class for all service exceptions from CloudFront service.</p>
 *
 *
 * @public
 */
export declare class GetFieldLevelEncryptionConfigCommand extends GetFieldLevelEncryptionConfigCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: GetFieldLevelEncryptionConfigRequest;
            output: GetFieldLevelEncryptionConfigResult;
        };
        sdk: {
            input: GetFieldLevelEncryptionConfigCommandInput;
            output: GetFieldLevelEncryptionConfigCommandOutput;
        };
    };
}
